@@ -17,10 +17,10 @@ mode=to.integer(mode),
 lpivot=to.integer(lpivot),
 l1=to.integer(l1),
 m=to.integer(m),
-u=to.double(u),
+u=as.double(u),
 iue=to.integer(iue),
-up=to.double(up),
-c=to.double(c),
+up=as.double(up),
+c=as.double(c),
 ice=to.integer(ice),
 icv=to.integer(icv),
 ncv=to.integer(ncv),
