@@ -9,9 +9,9 @@ mdb <- nrow(b)
 mdc <- n
 c <- matrix(double(1),mdc,m)
 f.res <- .Fortran("msfd",
-a=to.double(a),
-b=to.double(b),
-c=to.double(c),
+a=as.double(a),
+b=as.double(b),
+c=as.double(c),
 n=to.integer(n),
 nn=to.integer(nn),
 m=to.integer(m),
